TUIRoomId constructor
- @Deprecated("You only need to fill in one of intRoomId and strRoomId. If both are filled, strRoomId will be used by default.")
Implementation
@Deprecated(
"You only need to fill in one of intRoomId and strRoomId. If both are filled, strRoomId will be used by default.")
const TUIRoomId({required this.intRoomId, required this.strRoomId});