TUIInvitation class

Invitation information.

Constructors

TUIInvitation({TUIInvitationStatus status = TUIInvitationStatus.none, TUIUserInfo? invitee, TUIUserInfo? inviter})
TUIInvitation.fromJson(Map<String, dynamic> dataMap)

Properties

hashCode int
The hash code for this object.
no setterinherited
invitee TUIUserInfo?
Invitee information.
getter/setter pair
inviter TUIUserInfo?
Inviter information.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status TUIInvitationStatus
Invitation status.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited