TUIInvitationCode enum

Invitation code for invite users result.

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

success → const TUIInvitationCode

Invitation success.

alreadyInInvitationList → const TUIInvitationCode

User is already in invitation list.

alreadyInConference → const TUIInvitationCode

User is already in conference.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
value() int

Available on TUIInvitationCode, provided by the TUIInvitationCodeExt extension

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TUIInvitationCode>
A constant List of the values in this enum, in order of their declaration.