TUIInviteUsersResult class

Invite users result.

Constructors

TUIInviteUsersResult.fromJson(Map<String, dynamic> dataMap)

Properties

hashCode int
The hash code for this object.
no setterinherited
resultMap Map<String, TUIInvitationCode>
Result map, key is userId, value is invitation code.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited