TUIConferenceModifyFlag enum

Scheduled conference information modify flag.

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

none → const TUIConferenceModifyFlag

None

roomName → const TUIConferenceModifyFlag

Conference name

disableMessage → const TUIConferenceModifyFlag

Whether to disable all members from sending messages.

disableCamera → const TUIConferenceModifyFlag

Whether to disable all members from turning on the camera.

disableMicrophone → const TUIConferenceModifyFlag

Whether to disable all members from turning on the microphone.

disableScreenSharing → const TUIConferenceModifyFlag

Whether to disable all members from screen sharing.

password → const TUIConferenceModifyFlag

Room password.

reminderSecondsBeforeStart → const TUIConferenceModifyFlag

Reminder time before conference start.

scheduleStartTime → const TUIConferenceModifyFlag

Scheduled start time. The default is the current time.

scheduleEndTime → const TUIConferenceModifyFlag

Scheduled end time.The default is one hour after the scheduled start time.The minimum duration of a conference cannot be less than 5 minutes and the maximum duration cannot exceed 24 hours.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
value() int

Available on TUIConferenceModifyFlag, provided by the TUIConferenceModifyFlagExt extension

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TUIConferenceModifyFlag>
A constant List of the values in this enum, in order of their declaration.