TUIRequestCompletion class

Constructors

TUIRequestCompletion({required SeatRequestOnAccepted onAccepted, required SeatRequestOnRejected onRejected, required SeatRequestOnCancelled onCancelled, required SeatRequestOnTimeout onTimeout, required SeatRequestOnError onError})

Properties

hashCode int
The hash code for this object.
no setterinherited
onAccepted SeatRequestOnAccepted
getter/setter pair
onCancelled SeatRequestOnCancelled
getter/setter pair
onError SeatRequestOnError
getter/setter pair
onRejected SeatRequestOnRejected
getter/setter pair
onTimeout SeatRequestOnTimeout
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited