TUIUserSearchResult class

5.2 TUIUserSearchResult Definition

Constructors

TUIUserSearchResult()
TUIUserSearchResult.fromJson(Map<String, dynamic> jsonMap)

Properties

cursor String
Cursor to retrieve the next batch of member lists
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userInfoList List<TUIUserInfo>
Member Information List
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited