DeprecatedRoomEngineAPI class abstract

Implementers

Constructors

DeprecatedRoomEngineAPI()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchCamera(bool isFrontCamera) Future<int?>
////////////////////////////////////////////////////////////////////////////// ////////////////////////////////////////////////////////////////////////////// Switch front or rear camera
takeSeat(int seatIndex, int timeout, TUIRequestCallback? requestCallback) TUIRequest
takeUserOnSeatByAdmin(int seatIndex, String userId, int timeout, TUIRequestCallback? requestCallback) TUIRequest
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited